/**
 * \file InterfaceADS612x.c
 * \brief Arquivo de implementao do driver do ADS612x.
 *
 * \author Universidade Tecnolgica Federal do Paran - UTFPR
 * \author Laboratrio de Automao e Sistemas de Controle Avanado - LASCA
 * \author ENGAUT Engenharia e Automao LTDA - ME
 *
 * Projeto CAMITATIBA - Arquivo de implementao do driver dos conversores A/D das entradas
 * de aquisio, o ADS612x.
 *
 * Revises: nenhuma
 *
 * \date 01/04/2011
 * \author Rafael Jos Daciuk
 */

/*==================================================================
 * Incluses de Arquivos
 ==================================================================*/
#include "SonicLab.h"
#include "SonicLabDriver.h"

/*==================================================================
 * Implementaes de Funes
 ==================================================================*/

/**
 * \fn void ADS612x_Inicializa()
 * \brief Funo que inicializa os conversores A/D de entrada de aquisio.
 *
 * Esta funo inicializa os conversores A/D de entrada da Placa de Aquisio v2.0
 * setando as configuraes iniciais dos ADS612x.
 *
 */
void ADS612x_Inicializa()
{
	// aguarda a SPI do ADS612x ficar disponvel para envio de dados
	while (!SPI_VerificaEnvio(SPI_AQUIS));
	// configura o registrador 00 do ADS612x
	SPI_Envia(SPI_AQUIS, SPI_AQUIS_AD_FORMAT, SPI_AQUIS_SCSN, AQUIS_AD_REG00);
	// aguarda a SPI do ADS612x ficar disponvel para envio de dados
	while (!SPI_VerificaEnvio(SPI_AQUIS));
	// configura o registrador 04 do ADS612x
	SPI_Envia(SPI_AQUIS, SPI_AQUIS_AD_FORMAT, SPI_AQUIS_SCSN, AQUIS_AD_REG04);
	// aguarda a SPI do ADS612x ficar disponvel para envio de dados
	while (!SPI_VerificaEnvio(SPI_AQUIS));
	// configura o registrador 09 do ADS612x
	SPI_Envia(SPI_AQUIS, SPI_AQUIS_AD_FORMAT, SPI_AQUIS_SCSN, AQUIS_AD_REG09);
	// aguarda a SPI do ADS612x ficar disponvel para envio de dados
	while (!SPI_VerificaEnvio(SPI_AQUIS));
	// configura o registrador 0A do ADS612x
	SPI_Envia(SPI_AQUIS, SPI_AQUIS_AD_FORMAT, SPI_AQUIS_SCSN, AQUIS_AD_REG0A);
	// aguarda a SPI do ADS612x ficar disponvel para envio de dados
	while (!SPI_VerificaEnvio(SPI_AQUIS));
	// configura o registrador 0B do ADS612x
	SPI_Envia(SPI_AQUIS, SPI_AQUIS_AD_FORMAT, SPI_AQUIS_SCSN, AQUIS_AD_REG0B);
	// aguarda a SPI do ADS612x ficar disponvel para envio de dados
	while (!SPI_VerificaEnvio(SPI_AQUIS));
	// configura o registrador 0C do ADS612x
	SPI_Envia(SPI_AQUIS, SPI_AQUIS_AD_FORMAT, SPI_AQUIS_SCSN, AQUIS_AD_REG0C);
	// aguarda a SPI do ADS612x ficar disponvel para envio de dados
	while (!SPI_VerificaEnvio(SPI_AQUIS));
	// configura o registrador 0E do ADS612x
	SPI_Envia(SPI_AQUIS, SPI_AQUIS_AD_FORMAT, SPI_AQUIS_SCSN, AQUIS_AD_REG0E);
	// aguarda a SPI do ADS612x ficar disponvel para envio de dados
	while (!SPI_VerificaEnvio(SPI_AQUIS));
	// configura o registrador 0F do ADS612x
	SPI_Envia(SPI_AQUIS, SPI_AQUIS_AD_FORMAT, SPI_AQUIS_SCSN, AQUIS_AD_REG0F);
}
