/**
 * \file InterfaceExcitacao.h
 * \brief Arquivo header da interface com a Placa de Excitacao v1.0.
 *
 * \author Universidade Tecnolgica Federal do Paran - UTFPR
 * \author Laboratrio de Automao e Sistemas de Controle Avanado - LASCA
 * \author ENGAUT Engenharia e Automao LTDA - ME
 *
 * Projeto CAMITATIBA - Arquivo header da interface para interao com Placa de Excitacao v1.0.
 *
 * Revises: nenhuma
 *
 * \date 02/04/2011
 * \author Rafael Jos Daciuk
 */

#ifndef INTERFACEEXCITACAO_H_
#define INTERFACEEXCITACAO_H_

/*==================================================================
 * Incluses de Arquivos
 ==================================================================*/

/*==================================================================
 * Definies
 ==================================================================*/
#define ENDERECO_CTRLREG			0x0	///< Definio do endereo do registrador CTRLREG na controladora de excitao
#define ENDERECO_CH1PW				0x1	///< Definio do endereo do registrador CH1PW na controladora de excitao
#define ENDERECO_CH2PW				0x2	///< Definio do endereo do registrador CH2PW na controladora de excitao
#define ENDERECO_CH3PW				0x3	///< Definio do endereo do registrador CH3PW na controladora de excitao
#define ENDERECO_EXCITCNT			0x4	///< Definio do endereo do registrador EXCITCNT na controladora de excitao
#define ENDERECO_EXCITPRDH			0x5	///< Definio do endereo do registrador EXCITPRDH na controladora de excitao
#define ENDERECO_EXCITPRDL			0x6	///< Definio do endereo do registrador EXCITPRDL na controladora de excitao

#define CTRLREG_EXCIT_DESL			0x000	///< Definio do valor a ser escrito no registrador CTRLREG para desligar a excitao
#define CH1PW_INICIAL				0x011	///< Definio do valor padro da largura de pulso do canal 1 (~225ns)
#define CH2PW_INICIAL				0x008	///< Definio do valor padro da largura de pulso do canal 2 (~100ns)
#define CH3PW_INICIAL				0x011	///< Definio do valor padro da largura de pulso do canal 3 (~225ns)
#define EXCITCNT_INICIAL			0x005	///< Definio do valor padro da configurao da quantidade de excitaes (5 vezes)
#define EXCITPRDH_INICIAL			((0x16E35 >> 12) & 0xFFF)	///< Definio do valor padro da parte alta do perodo da frequncia de excitao (para 100Hz)
#define EXCITPRDL_INICIAL			(0x16E35 & 0xFFF)	///< Definio do valor padro da parte baixa do perodo da frequncia de excitao (para 100Hz)

/*==================================================================
 * Typedefs
 ==================================================================*/
/**
 * \struct ExcitConfigEstrutura
 * \brief Estrutura contendo os registradores de configurao da controladora de excitao.
 */
typedef struct
{
	Uint16 regCtrlReg;	///< Campo representando o registrador de controle (CTRLREG)
	Uint16 regCh1Pw;	///< Campo representando o registrador da largura de pulso do canal 1 (CH1PW)
	Uint16 regCh2Pw;	///< Campo representando o registrador da largura de pulso do canal 2 (CH2PW)
	Uint16 regCh3Pw;	///< Campo representando o registrador da largura de pulso do canal 3 (CH3PW)
	Uint16 regExcitCnt;	///< Campo representando o registrador de quantidade de excitaes (EXCITCNT)
	Uint16 regExcitPrdH;	///< Campo representando o registrador da parte alta do perodo da frequncia de excitao (EXCITPRDH)
	Uint16 regExcitPrdL;	///< Campo representando o registrador da parte baixa do perodo da frequncia de excitao (EXCITPRDL)
} ExcitConfigEstrutura;

/*==================================================================
 * Prottipos de Funes
 ==================================================================*/
void ExcitacaoInicializa();
void ExcitacaoConfigura();
void ExcitacaoDesliga();
void ExcitacaoGravaReg(Uint8 enderecoReg, Uint16 valorReg);
Uint16 ExcitacaoLeReg(Uint8 enderecoReg);

#endif /* INTERFACEEXCITACAO_H_ */
