/**
 * \file SonicLabDriver.h
 * \brief Arquivo header para os drivers dos perifricos do OMAP-L138.
 *
 * \author Universidade Tecnolgica Federal do Paran - UTFPR
 * \author Laboratrio de Automao e Sistemas de Controle Avanado - LASCA
 * \author ENGAUT Engenharia e Automao LTDA - ME
 *
 * Projeto CAMITATIBA - Arquivo header para os drivers dos perifricos do OMAP-L138.
 *
 * Revises: nenhuma
 *
 * \date 24/03/2011
 * \author Rafael Jos Daciuk
 */

#ifndef SONICLABDRIVER_H_
#define SONICLABDRIVER_H_

/*==================================================================
 * Incluses de Arquivos
 ==================================================================*/
#include <ti/psp/cslr/csl_types.h>
#include <ti/psp/cslr/cslr_psc_OMAPL138.h>
#include <ti/psp/cslr/soc_OMAPL138.h>

/*==================================================================
 * Definies
 ==================================================================*/
#define QDMA_FIFO_AD_CHANNEL		0	///< Define o canal QDMA que ser usado nas transferncias das FIFO's dos AD's para a memria externa DDR2
#define QDMA_FIFO_AD_PARAM_ENTRY	32	///< Define o local dos parmetros de configurao das transferncias das FIFO's dos AD's para a memria externa DDR2
#define QDMA_FIFO_AD_TCC			1	///< Define o TCC (Transfer Complete Code) que identificar qua a transferncia por EDMA que foi completada  a das FIFO's
#define QDMA_FIFO_AD_EVT			CSL_INTC_EVENTID_EDMA3_0_CC0_INT1	///< Define qual o evento de interrupo que representa a interrupo da EDMA responsvel pela transferncia de dados das FIFO's dos AD's
#define QDMA_FIFO_AD_VECT			12	///< Define qual o vetor de interrupo trata a interrupo da EDMA responsvel pela transferncia de dados das FIFO's dos AD's

#define SPI_AQUIS					1	///< Define qual dos perifricos SPI  usado na comunicao com a Placa de Aquisio v2.0
#define SPI_EXCIT					1	///< Define qual dos perifricos SPI  usado na comunicao com a Placa de Excitao v1.0
#define SPI_AQUIS_AD_FORMAT			0	///< Define qual o registrador de formato de dados SPI que contm o formato correto para comunicar com os AD's da Aquisio
#define SPI_PT100_AD_FORMAT			1	///< Define qual o registrador de formato de dados SPI que contm o formato correto para comunicar com o AD do PT100
#define SPI_EXCIT_FORMAT			2	///< Define qual o registrador de formato de dados SPI que contm o formato correto para comunicar com o Controlador de Excitao
#define SPI_AQUIS_SCSN				2	///< Define qual o pino de chip select da SPI  usado na Placa de Aquisio v2.0
#define SPI_EXCIT_SCSN				3	///< Define qual o pino de chip select da SPI  usado na Placa de Excitao v1.0

#define GPIO_CPLD_MRS_BANK			0	///< Define qual o banco de GPIO's contm o pino que ser utilizado para o sinal de Reset da CPLD da Placa de Aquisio v2.0
#define GPIO_CPLD_MRS_PIN			7	///< Define qual o nmero do pino de GPIO ser utilizado para o sinal de Reset da CPLD da Placa de Aquisio v2.0
#define GPIO_EXCIT_INT_BANK			0	///< Define qual o banco de GPIO's contm o pino que ser utilizado como entrada de interrupo proveniente do Controlador de Excitao
#define GPIO_EXCIT_INT_PIN			14	///< Define qual o nmero do pino de GPIO ser utilizado como entrada de interrupo proveniente do Controlador de Excitao
#define GPIO_EXCIT_INT_EVT			CSL_INTC_EVENTID_GPIO_BNK0_INT	///< Define qual o evento de interrupo que representa a interrupo da Excitao
#define GPIO_EXCIT_INT_VECT			4	///< Define qual o vetor de interrupo trata a interrupo da Excitao

/*==================================================================
 * Prottipos de Funes
 ==================================================================*/
void InicializaOmap();
void InicializaMemorias();

void PSC_Inicializa();
void PSC_MudaEstadoPerif(CSL_PscRegsOvly pscRegs, Uint32 domain, Uint8 module, Uint8 next_state);

void PLLC_Inicializa();

void DDR2_Inicializa();

void EMIFA_Inicializa();
void EMIFA_Cs2DiminuiVeloc();
void EMIFA_Cs2AumentaVeloc();

void DSPINTC_Inicializa();
void DSPINTC_LimpaEvento(Uint8 vetor, Uint8 evento);

void EDMA3_Inicializa();
void EDMA3_ConfFifoAd(unsigned int tamanhoAmostras, unsigned short *destinoCanal1, unsigned short *destinoCanal2, unsigned short *destinoCanal3);
void EDMA3_DisparaFifoAd();
Uint32 EDMA3_LeInt();
void EDMA3_LimpaInt(Uint8 tcc);

void TIMER_Inicializa();

void GPIO_Inicializa();
void GPIO_SetaPino(Uint8 bancoGpio, Uint8 pinoGpio, Uint8 valor);

void SPI_Inicializa();
void SPI_Envia(Uint8 spiNum, Uint8 regFormato, Uint8 scsNum, Uint16 dado);
Uint8 SPI_VerificaEnvio(Uint8 spiNum);

#endif /* SONICLABDRIVER_H_ */
