/**
 * \file SonicLab.h
 * \brief Arquivo header do firmware de aquisio de dados de ultrassom.
 *
 * \author Universidade Tecnolgica Federal do Paran - UTFPR
 * \author Laboratrio de Automao e Sistemas de Controle Avanado - LASCA
 * \author ENGAUT Engenharia e Automao LTDA - ME
 *
 * Projeto CAMITATIBA - Arquivo header contendo as definies gerais do sistema de aquisio de
 * dados de ultrassom, bem como os prottipos das funes implementadas no arquivo principal do
 * firmware.
 *
 * Revises: nenhuma
 *
 * \date 24/03/2011
 * \author Rafael Jos Daciuk
 */

#ifndef SONICLAB_H_
#define SONICLAB_H_

/*==================================================================
 * Incluses de Arquivos
 ==================================================================*/


/*==================================================================
 * Definies
 ==================================================================*/
#define CS_PLACA_AQUIS_BASE		0x60000000							///< Endereo base para acesso aos perifricos da Placa de Aquisio v2.0
#define CS_AD_FLAGS       		(CS_PLACA_AQUIS_BASE + (5 << 14))	///< Endereo base para leitura dos flags das FIFOs
#define CS_AQUIS_CONF      		(CS_PLACA_AQUIS_BASE + (4 << 14))	///< Endereo base do controle de aquisio (serial enable, reset e powerdown dos ADs; escrita e reset das FIFOS)
//#define AD_CONF_1       		0xA03E0000		// Configuracao FIFO 1
//#define AD_CONF_2       		0xA03D0000		// Configuracao FIFO 2
//#define AD_CONF_3       		0xA03C0000		// Configuracao FIFO 3
#define AQUIS_AD_REG00			((0x00<<11) + 0x0000)		///< Valor a ser enviado aos ADs para configurao do registrador 00 via SPI
#define AQUIS_AD_REG04			((0x04<<11) + 0x0000)		///< Valor a ser enviado aos ADs para configurao do registrador 04 via SPI
#define AQUIS_AD_REG09			((0x09<<11) + 0x0000)		///< Valor a ser enviado aos ADs para configurao do registrador 09 via SPI
#define AQUIS_AD_REG0A			((0x0A<<11) + 0x0400)//((0x0A<<11) + 0x0480)		///< Valor a ser enviado aos ADs para configurao do registrador 0A via SPI (0x480) --> o 8  condicao de teste em rampa
#define AQUIS_AD_REG0B			((0x0B<<11) + 0x0000)		///< Valor a ser enviado aos ADs para configurao do registrador 0B via SPI
#define AQUIS_AD_REG0C			((0x0C<<11) + 0x0000)		///< Valor a ser enviado aos ADs para configurao do registrador 0C via SPI
#define AQUIS_AD_REG0E			((0x0E<<11) + 0x0000)		///< Valor a ser enviado aos ADs para configurao do registrador 0E via SPI
#define AQUIS_AD_REG0F			((0x0F<<11) + 0x00F0)		///< Valor a ser enviado aos ADs para configurao do registrador 0F via SPI

#define CS_AD_1       			(CS_PLACA_AQUIS_BASE + (1 << 14))		///< Endereo base para leitura dos dados da FIFO1 (AD1)
#define CS_AD_2       			(CS_PLACA_AQUIS_BASE + (2 << 14))		///< Endereo base para leitura dos dados da FIFO2 (AD2)
#define CS_AD_3       			(CS_PLACA_AQUIS_BASE + (3 << 14))		///< Endereo base para leitura dos dados da FIFO3 (AD3)

#define CS_AMP_CONF       		(CS_PLACA_AQUIS_BASE + (6 << 14))//(CS_PLACA_AQUIS_BASE + (0x00180000 >> 6))		///< Endereo base do controle do ganho dos amplificadores

// valores utilizados na programao do gerador de clock dos ADs
#define CLOCK_CTRL_BASE			(CS_PLACA_AQUIS_BASE + (9 << 14))		///< Endereo base do controlador SMBus para o gerador de clock dos ADs
#define CLOCK_CTRL_MADR			(CLOCK_CTRL_BASE + (0x8C << 2))		///< Endereo do registrador MADR do controlador SMBus
#define CLOCK_CTRL_MBCR			(CLOCK_CTRL_BASE + (0x90 << 2))		///< Endereo do registrador MBCR do controlador SMBus
#define CLOCK_CTRL_MBSR			(CLOCK_CTRL_BASE + (0x92 << 2))		///< Endereo do registrador MBSR do controlador SMBus
#define CLOCK_CTRL_MBDR			(CLOCK_CTRL_BASE + (0x94 << 2))		///< Endereo do registrador MBDR do controlador SMBus
#define CLOCK_I2C_ADDR			0x70		///< Endereo I2C do gerador de clock dos ADs

#define SI5338_DELAY			288000	///< Nmero de iteraes em loop para um delay de ~12ms, para esperar o gerador de clock SI5335 ficar pronto aps o Reset
#define LOCK_MASK				0x15	///< Valor para verificao do status de LOCK do gerador de clock SI5338
#define LOS_MASK				0x04	///< Valor para verificao do status de LOS do gerador de clock SI5338


#define USB_BUFFER_SIZE 2048	///< Tamanho do buffer para transmisso de dados via USB
//#define SAMPLES_SIZE 2048
//#define NUMBER_OF_US_WAVES 15360

#define EXT_MEM 64000000	///< Tamanho utilizvel de memria externa (SDRAM)

#define GANHO_AMP_1 0xB							///< Ganho do Amplificador 1 de 0x0 (-5dB) a 0xF (+40dB)
#define GANHO_AMP_2 0xB							///< Ganho do Amplificador 2 de 0x0 (-5dB) a 0xF (+40dB)
#define GANHO_AMP_3 0xB							///< Ganho do Amplificador 3 de 0x0 (-5dB) a 0xF (+40dB)

#ifndef TRUE
#define FALSE ((Bool)0)
#define TRUE  ((Bool)1)
#endif

/*==================================================================
 * Typedefs
 ==================================================================*/
typedef char				BOOLEAN;
typedef char				CHAR_8;
typedef char				INT_8;
typedef	unsigned char		UNS_8;
typedef	short int			INT_16;
typedef unsigned short int	UNS_16;
typedef	unsigned int		UNS_32;
typedef	int					INT_32;
typedef unsigned long		UNS_40;
typedef long				INT_40;
typedef float				FLT_32;
typedef double				DBL_64;

/*==================================================================
 * Prottipos de Funes
 ==================================================================*/
//void init_hwi();
//void processa();
//void EDMAConfig();
//void InitFIFOAD1();
//
//void vConfigGPIOs();
//void vReset();
//void forceStop();
//
//void enviaOndasUSB();
//void alocaMemoria();
//void desalocaMemoria();
//void aquisicao();
//void configSalvaOnda();
//void salvaOnda();
//void enviaCabecalhoUSB(unsigned char);
//
//void I2C_Init();
//void I2C_ByteWrite(unsigned char addr, unsigned char dat);
//unsigned char I2C_ByteRead(unsigned char addr);
//void ClockGenConfig(const Reg_Data *Reg_Store);
//
//void ExcitConfig();
//
//void InitSPI();

/*==================================================================
 * Prottipos de Interrupes
 ==================================================================*/
//interrupt void intUSB_isr();
//interrupt void timer1_isr();
//interrupt void serial_isr();
//interrupt void edma7_isr();

#endif /* SONICLAB_H_ */
